==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmiProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * (deprecated) The properties that define which ECS-optimized AMI is used.
 * <p>
 * @deprecated see {@link EcsOptimizedImage}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.494Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmiProps")
@software.amazon.jsii.Jsii.Proxy(EcsOptimizedAmiProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface EcsOptimizedAmiProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The Amazon Linux generation to use.
     * <p>
     * Default: AmazonLinuxGeneration.AmazonLinux2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
        return null;
    }

    /**
     * (deprecated) The ECS-optimized AMI variant to use.
     * <p>
     * Default: AmiHardwareType.Standard
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
        return null;
    }

    /**
     * (deprecated) The Windows Server version to use.
     * <p>
     * Default: none, uses Linux generation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<EcsOptimizedAmiProps> {
        private software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getGeneration}
         * @param generation The Amazon Linux generation to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.generation = generation;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getHardwareType}
         * @param hardwareType The ECS-optimized AMI variant to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.hardwareType = hardwareType;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getWindowsVersion}
         * @param windowsVersion The Windows Server version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.windowsVersion = windowsVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsOptimizedAmiProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public EcsOptimizedAmiProps build() {
            return new Jsii$Proxy(generation, hardwareType, windowsVersion);
        }
    }

    /**
     * An implementation for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsOptimizedAmiProps {
        private final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.generation = software.amazon.jsii.Kernel.get(this, "generation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration.class));
            this.hardwareType = software.amazon.jsii.Kernel.get(this, "hardwareType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.AmiHardwareType.class));
            this.windowsVersion = software.amazon.jsii.Kernel.get(this, "windowsVersion", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation, final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType, final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.generation = generation;
            this.hardwareType = hardwareType;
            this.windowsVersion = windowsVersion;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
            return this.generation;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
            return this.hardwareType;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
            return this.windowsVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGeneration() != null) {
                data.set("generation", om.valueToTree(this.getGeneration()));
            }
            if (this.getHardwareType() != null) {
                data.set("hardwareType", om.valueToTree(this.getHardwareType()));
            }
            if (this.getWindowsVersion() != null) {
                data.set("windowsVersion", om.valueToTree(this.getWindowsVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.EcsOptimizedAmiProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsOptimizedAmiProps.Jsii$Proxy that = (EcsOptimizedAmiProps.Jsii$Proxy) o;

            if (this.generation != null ? !this.generation.equals(that.generation) : that.generation != null) return false;
            if (this.hardwareType != null ? !this.hardwareType.equals(that.hardwareType) : that.hardwareType != null) return false;
            return this.windowsVersion != null ? this.windowsVersion.equals(that.windowsVersion) : that.windowsVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.generation != null ? this.generation.hashCode() : 0;
            result = 31 * result + (this.hardwareType != null ? this.hardwareType.hashCode() : 0);
            result = 31 * result + (this.windowsVersion != null ? this.windowsVersion.hashCode() : 0);
            return result;
        }
    }
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmiProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * (deprecated) The properties that define which ECS-optimized AMI is used.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * ComputeEnvironment myComputeEnv = ComputeEnvironment.Builder.create(this, "ComputeEnv")
 *         .computeResources(ComputeResources.builder()
 *                 .image(EcsOptimizedAmi.Builder.create()
 *                         .generation(AmazonLinuxGeneration.AMAZON_LINUX_2)
 *                         .build())
 *                 .vpc(vpc)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @deprecated see {@link EcsOptimizedImage}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.793Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmiProps")
@software.amazon.jsii.Jsii.Proxy(EcsOptimizedAmiProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface EcsOptimizedAmiProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) Whether the AMI ID is cached to be stable between deployments.
     * <p>
     * By default, the newest image is used on each deployment. This will cause
     * instances to be replaced whenever a new version is released, and may cause
     * downtime if there aren't enough running instances in the AutoScalingGroup
     * to reschedule the tasks on.
     * <p>
     * If set to true, the AMI ID will be cached in <code>cdk.context.json</code> and the
     * same value will be used on future runs. Your instances will not be replaced
     * but your AMI version will grow old over time. To refresh the AMI lookup,
     * you will have to evict the value from the cache using the <code>cdk context</code>
     * command. See https://docs.aws.amazon.com/cdk/latest/guide/context.html for
     * more information.
     * <p>
     * Can not be set to <code>true</code> in environment-agnostic stacks.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getCachedInContext() {
        return null;
    }

    /**
     * (deprecated) The Amazon Linux generation to use.
     * <p>
     * Default: AmazonLinuxGeneration.AmazonLinux2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
        return null;
    }

    /**
     * (deprecated) The ECS-optimized AMI variant to use.
     * <p>
     * Default: AmiHardwareType.Standard
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
        return null;
    }

    /**
     * (deprecated) The Windows Server version to use.
     * <p>
     * Default: none, uses Linux generation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<EcsOptimizedAmiProps> {
        java.lang.Boolean cachedInContext;
        software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getCachedInContext}
         * @param cachedInContext Whether the AMI ID is cached to be stable between deployments.
         *                        By default, the newest image is used on each deployment. This will cause
         *                        instances to be replaced whenever a new version is released, and may cause
         *                        downtime if there aren't enough running instances in the AutoScalingGroup
         *                        to reschedule the tasks on.
         *                        <p>
         *                        If set to true, the AMI ID will be cached in <code>cdk.context.json</code> and the
         *                        same value will be used on future runs. Your instances will not be replaced
         *                        but your AMI version will grow old over time. To refresh the AMI lookup,
         *                        you will have to evict the value from the cache using the <code>cdk context</code>
         *                        command. See https://docs.aws.amazon.com/cdk/latest/guide/context.html for
         *                        more information.
         *                        <p>
         *                        Can not be set to <code>true</code> in environment-agnostic stacks.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cachedInContext(java.lang.Boolean cachedInContext) {
            this.cachedInContext = cachedInContext;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getGeneration}
         * @param generation The Amazon Linux generation to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.generation = generation;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getHardwareType}
         * @param hardwareType The ECS-optimized AMI variant to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.hardwareType = hardwareType;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getWindowsVersion}
         * @param windowsVersion The Windows Server version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.windowsVersion = windowsVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsOptimizedAmiProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public EcsOptimizedAmiProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsOptimizedAmiProps {
        private final java.lang.Boolean cachedInContext;
        private final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cachedInContext = software.amazon.jsii.Kernel.get(this, "cachedInContext", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.generation = software.amazon.jsii.Kernel.get(this, "generation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration.class));
            this.hardwareType = software.amazon.jsii.Kernel.get(this, "hardwareType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.AmiHardwareType.class));
            this.windowsVersion = software.amazon.jsii.Kernel.get(this, "windowsVersion", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cachedInContext = builder.cachedInContext;
            this.generation = builder.generation;
            this.hardwareType = builder.hardwareType;
            this.windowsVersion = builder.windowsVersion;
        }

        @Override
        public final java.lang.Boolean getCachedInContext() {
            return this.cachedInContext;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
            return this.generation;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
            return this.hardwareType;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
            return this.windowsVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCachedInContext() != null) {
                data.set("cachedInContext", om.valueToTree(this.getCachedInContext()));
            }
            if (this.getGeneration() != null) {
                data.set("generation", om.valueToTree(this.getGeneration()));
            }
            if (this.getHardwareType() != null) {
                data.set("hardwareType", om.valueToTree(this.getHardwareType()));
            }
            if (this.getWindowsVersion() != null) {
                data.set("windowsVersion", om.valueToTree(this.getWindowsVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.EcsOptimizedAmiProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsOptimizedAmiProps.Jsii$Proxy that = (EcsOptimizedAmiProps.Jsii$Proxy) o;

            if (this.cachedInContext != null ? !this.cachedInContext.equals(that.cachedInContext) : that.cachedInContext != null) return false;
            if (this.generation != null ? !this.generation.equals(that.generation) : that.generation != null) return false;
            if (this.hardwareType != null ? !this.hardwareType.equals(that.hardwareType) : that.hardwareType != null) return false;
            return this.windowsVersion != null ? this.windowsVersion.equals(that.windowsVersion) : that.windowsVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cachedInContext != null ? this.cachedInContext.hashCode() : 0;
            result = 31 * result + (this.generation != null ? this.generation.hashCode() : 0);
            result = 31 * result + (this.hardwareType != null ? this.hardwareType.hashCode() : 0);
            result = 31 * result + (this.windowsVersion != null ? this.windowsVersion.hashCode() : 0);
            return result;
        }
    }
}
